pub struct AamCompiler;Implementations
Sourceimpl AamCompiler
impl AamCompiler
Sourcepub fn cook(source_path: impl AsRef<Path>) -> Result<PathBuf, Vec<AamlError>>
pub fn cook(source_path: impl AsRef<Path>) -> Result<PathBuf, Vec<AamlError>>
Compiles a text .aam asset into a cooked SoA .aam.bin blob.
Errors
Returns errors if the source file cannot be read, fails to parse/validate, fails to serialize or write the cooked binary cache, or encounters I/O issues.