pub struct AamLoader;Implementations
Sourceimpl AamLoader
impl AamLoader
Sourcepub fn load_fast(
source_path: impl AsRef<Path>,
) -> Result<MappedAam, Vec<AamlError>>
pub fn load_fast( source_path: impl AsRef<Path>, ) -> Result<MappedAam, Vec<AamlError>>
Loads a cooked .aam.bin cache into a zero-copy memory-mapped view.
Rebuilds the cache if the source .aam file is newer than the .aam.bin.
Errors
Returns errors if the file cannot be read, the cache cannot be memory-mapped, or the source file is invalid and rebuilding the cache fails.