#[repr(C)]pub struct FlatNode {
pub kind: u32,
pub parent: u32,
pub first_child: u32,
pub next_sibling: u32,
}Expand description
Fixed-size (16-byte) node used by the cooked SoA layout.
Fields
kind: u32parent: u32first_child: u32next_sibling: u32Trait Implementations
Sourceimpl Archive for FlatNode
impl Archive for FlatNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedFlatNode
type Archived = ArchivedFlatNode
The archived representation of this type. Read more
Sourcetype Resolver = FlatNodeResolver
type Resolver = FlatNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
impl Copy for FlatNode