#[repr(C)]pub struct SymbolEntry {
pub hash: u64,
pub node_index: u32,
}Fields
hash: u64node_index: u32Trait Implementations
Sourceimpl Archive for SymbolEntry
impl Archive for SymbolEntry
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSymbolEntry
type Archived = ArchivedSymbolEntry
The archived representation of this type. Read more
Sourcetype Resolver = SymbolEntryResolver
type Resolver = SymbolEntryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for SymbolEntry
impl Clone for SymbolEntry
Sourcefn clone(&self) -> SymbolEntry
fn clone(&self) -> SymbolEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SymbolEntry
Sourceimpl Debug for SymbolEntry
impl Debug for SymbolEntry
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SymbolEntry, __D> for Archived<SymbolEntry>
impl<__D: Fallible + ?Sized> Deserialize<SymbolEntry, __D> for Archived<SymbolEntry>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SymbolEntry, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SymbolEntry, <__D as Fallible>::Error>
Deserializes using the given deserializer