pub struct SchemaField { /* private fields */ }Expand description
A single field declaration inside a @schema block.
Fields declared with SchemaField::optional are emitted with a * suffix,
meaning the key does not have to be present in the data map, but its value is
still type-checked when it is present.
Example
use aam_core::builder::SchemaField;
let f = SchemaField::required("host", "string");
assert_eq!(f.to_aaml(), "host: string");
let g = SchemaField::optional("debug", "bool");
assert_eq!(g.to_aaml(), "debug*: bool");Implementations
Sourceimpl SchemaField
impl SchemaField
Sourcepub fn required(name: impl Into<String>, type_name: impl Into<String>) -> Self
pub fn required(name: impl Into<String>, type_name: impl Into<String>) -> Self
Creates a required field (rendered as name: type).
Sourcepub fn optional(name: impl Into<String>, type_name: impl Into<String>) -> Self
pub fn optional(name: impl Into<String>, type_name: impl Into<String>) -> Self
Creates an optional field (rendered as name*: type).
pub fn to_aaml_writer(&self, w: impl Write) -> Result