Module error

Module error 

Error types for the AAML parser and validation pipeline with beautiful colored output.

Structs

ErrorDiagnostics
Error diagnostics with “What”, “Why”, and “Fix” guidance (inspired by Cargo).

Enums

AamlError
All errors that can be produced while parsing or validating an AAML document.

Functions

set_error_render_context

Type Aliases

AamError
Backward-compatible alias used by some bindings.