pub enum ParseTask<'a> {
ResolveModuleReference {
module_name: Cow<'a, str>,
scope: Cow<'a, str>,
line: usize,
},
ResolveDeriveImport {
derive_path: Cow<'a, str>,
line: usize,
},
ProcessVariable {
variable_name: Cow<'a, str>,
value: Cow<'a, str>,
scope: Cow<'a, str>,
line: usize,
},
ManageScope {
scope: Cow<'a, str>,
is_entry: bool,
line: usize,
},
ExecuteDirective {
directive_name: Cow<'a, str>,
arguments: Cow<'a, str>,
line: usize,
},
RegisterType {
type_name: Cow<'a, str>,
type_spec: Cow<'a, str>,
line: usize,
},
RegisterSchema {
schema_name: Cow<'a, str>,
fields: Cow<'a, str>,
line: usize,
},
}Expand description
A declarative parsing task generated by the Parser.
Parse tasks represent operations that need to be performed on parsed modules, variables, and scopes. They enable deferred processing and analysis.
Variants
ResolveModuleReference
Resolve a module reference in a scope.
Fields
module_name: Name of the module to resolvescope: Current scope pathline: Source line number
ResolveDeriveImport
Resolve an imported file and apply its types and schemas to the context.
Fields
derive_path: Raw derive path (e.g.file.aam::SchemaName)line: Source line number
ProcessVariable
Process variable assignments in a scope.
Fields
variable_name: Name of the variablevalue: Variable valuescope: Scope pathline: Source line number
ManageScope
Manage the scope lifecycle (entry/exit).
Fields
scope: Scope pathis_entry: true for scope entry, false for exitline: Source line number
ExecuteDirective
Execute a directive (e.g., @import, @derive).
Fields
directive_name: Name of the directivearguments: Directive argumentsline: Source line number
RegisterType
Register a type definition from @type directive.
Fields
type_name: Name of the type being registeredtype_spec: Type specificationline: Source line number
RegisterSchema
Register a schema definition from the @schema directive.
Fields
schema_name: Name of the schemafields: Field definitionsline: Source line number
Implementations